@@ -1,6 +1,6 @@
 MESSAGE_KEY_CLIENT_ATTRIBUTE_NAME = 'messageKey'
 GROUP_KEY_CLIENT_ATTRIBUTE_NAME = 'groupKey'
-HEADERS_KEY_CLIENT_ATTRIBUTE_NAME = 'messageHeaders'
+MESSAGE_HEADERS_KEY_CLIENT_ATTRIBUTE_NAME = 'messageHeaders'
 
 MESSAGE_KEY_KEY = 'key'
 MESSAGE_QUEUE_KEY_KEY = 'queueKey'
